==> angelsrefining_0.7.17.zip: angelsrefining_0.7.17/prototypes/items/refining-ores.lua <==
data:extend(
{
{
    type = "item",
    name = "angels-ore1",
    icon = "__angelsrefining__/graphics/icons/angels-ore1.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "a[angels-ore1]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore2",
    icon = "__angelsrefining__/graphics/icons/angels-ore2.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "b[angels-ore2]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore3",
    icon = "__angelsrefining__/graphics/icons/angels-ore3.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "c[angels-ore3]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore4",
    icon = "__angelsrefining__/graphics/icons/angels-ore4.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "d[angels-ore4]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore5",
    icon = "__angelsrefining__/graphics/icons/angels-ore5.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "e[angels-ore5]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore6",
    icon = "__angelsrefining__/graphics/icons/angels-ore6.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "f[angels-ore6]",
    stack_size = 200
},
{
    type = "fluid",
    name = "thermal-water",
    icon = "__angelsrefining__/graphics/icons/water-thermal.png",
	default_temperature = 100,
    heat_capacity = "1KJ",
    base_color = {r = 1, g = 0.3, b = 0.1},
    flow_color = {r = 1, g = 0.3, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
--GEODES
  {
    type = "item",
    name = "geode-blue",
    icon = "__angelsrefining__/graphics/icons/geode-blue.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "geode-processing",
    stack_size = 200
  },
  {
    type = "item",
    name = "geode-cyan",
    icon = "__angelsrefining__/graphics/icons/geode-cyan.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "geode-processing",
    stack_size = 200
  },
  {
    type = "item",
    name = "geode-lightgreen",
    icon = "__angelsrefining__/graphics/icons/geode-lightgreen.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "geode-processing",
    stack_size = 200
  },
  {
    type = "item",
    name = "geode-purple",
    icon = "__angelsrefining__/graphics/icons/geode-purple.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "geode-processing",
    stack_size = 200
  },
  {
    type = "item",
    name = "geode-red",
    icon = "__angelsrefining__/graphics/icons/geode-red.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "geode-processing",
    stack_size = 200
  },
  {
    type = "item",
    name = "geode-yellow",
    icon = "__angelsrefining__/graphics/icons/geode-yellow.png",
    flags = {"goes-to-main-inventory"},
	subgroup = "geode-processing",
    stack_size = 200
  },
}
)

==> angelsrefining_0.9.9.zip: angelsrefining_0.9.9/prototypes/items/refining-ores.lua <==
data:extend(
{
{
    type = "item",
    name = "angels-ore1",
    icon = "__angelsrefining__/graphics/icons/angels-ore1.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "a[angels-ore1]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore2",
    icon = "__angelsrefining__/graphics/icons/angels-ore2.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "b[angels-ore2]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore3",
    icon = "__angelsrefining__/graphics/icons/angels-ore3.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "c[angels-ore3]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore4",
    icon = "__angelsrefining__/graphics/icons/angels-ore4.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "d[angels-ore4]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore5",
    icon = "__angelsrefining__/graphics/icons/angels-ore5.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "e[angels-ore5]",
    stack_size = 200
},
{
    type = "item",
    name = "angels-ore6",
    icon = "__angelsrefining__/graphics/icons/angels-ore6.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
	subgroup = "angels-ores",
    order = "f[angels-ore6]",
    stack_size = 200
},
{
    type = "fluid",
    name = "thermal-water",
    icon = "__angelsrefining__/graphics/icons/water-thermal.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.2KJ",
    base_color = {r = 1, g = 0.3, b = 0.1},
    flow_color = {r = 1, g = 0.3, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
}
)
